@@ -131,7 +131,7 @@ Print.prototype = {
         // write document
         var printdoc = this.printwindow.document;
 		printdoc.open();
-		printdoc.write("<html style=\"overflow:auto\"><head><title>" + this.printName + "</title>");
+		printdoc.write("<html style=\"overflow:auto\"><head><title>" + escapeHTML(this.printName || "") + "</title>");
 		printdoc.write("<link rel=\"stylesheet\" type=\"text/css\" href=\"print.css\"/>");
 		printdoc.write("</head><body style=\"width:95%; height:95%\">");
 		printdoc.write("<table class=\"detailprint\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\" style=\"width:100%\">");
@@ -260,7 +260,7 @@ Print.prototype = {
             success: function (win, guid) {
                 self.printwindow = win;
                 win.document.open();
-                win.document.write("<html style=\"overflow:auto\"><head><title>" + this.name + "</title>");
+                win.document.write("<html style=\"overflow:auto\"><head><title>" + escapeHTML(this.name || "") + "</title>");
                 win.document.write("<link rel=\"stylesheet\" type=\"text/css\" href=\"print.css\"/>");
                 win.document.write("</head><body style=\"width:95%; height:95%\">");
                 win.document.write(self.printdiv.innerHTML);
