@@ -293,10 +293,13 @@ function cs_saveConfiguration() {
 			configSetKey("gui.global.region.date.format", current_date_format);
 		}
 	}
-    triggerEvent("OX_Save_Configuration", false, false, function() {
+    triggerEvent("OX_Save_Configuration", false, false, function(cb) {
         if (languageChanged) {
             setLanguage(configGetKey("language"), function() {
                 cs_region_enter();
+                if (cb) {
+                	cb();
+                }
             });
         }
     });
