@@ -217,11 +217,12 @@ function format(string, params) {
  */
 function formatRaw(string, params) {
     var index = 0;
-    return String(string).replace(/%(([0-9]+)\$)?[A-Za-z]/g,
-        function(match, pos, n) {
+    return String(string).replace(/%(?:(([0-9]+)\$)?[A-Za-z]|(%))/g,
+        function(match, pos, n, percent) {
+            if (percent) return "%";
             if (pos) index = n - 1;
             return params[index++];
-        }).replace(/%%/, "%");
+        });
 }
 
 /**
