@@ -22,6 +22,7 @@ var lockedDetailInformation;
 
 //works only in editr mode...
 function deleteSearchInfoItem() {
+    infostoreSearchObject = null;
 	if(currentpath[0] == "infostore" && currentpath[1] == "list") {
 		loadLiveGridInfo();		
 	} else if(currentpath[0] == "infostore" && currentpath[1] == "split") {
@@ -31,6 +32,7 @@ function deleteSearchInfoItem() {
 }
 function searchInfoItem(sModule,sPattern) {
 	if (sModule=="infostore") {
+	    infostoreSearchObject = { module: sModule, pattern: sPattern };
 	    bSearchInfoItemMode = true;
         var criteria={};
         var search={ 
@@ -184,7 +186,11 @@ function replaceUserNames()
 function gridInfoListSort_Func(id, order) {
 	var criteria= { "folder_id" : activefolder };
 	gridInfoList.disablehover=!configGetKey("gui.effects.hover.infostore");
-    gridInfoList.enable(criteria,false);
+	if (infostoreSearchObject !== null) {
+        searchInfoItem(infostoreSearchObject.module, infostoreSearchObject.pattern);
+    } else {
+        gridInfoList.enable(criteria,false);
+    }
     bInfoListLoaded = true; 
 };
 
@@ -273,11 +279,9 @@ function loadLiveGridInfo()
                     style: {textAlign: "right"},
                     width: "6em",
                     set: function (div, text) {
-                        if(text < 0 )
-                            var sDisplayString = '';
-                        else
-                        {
-                            var sDisplayString = bytesToString(text);;
+                        var sDisplayString = '';
+                        if (text >= 0 ) {
+                            sDisplayString = bytesToString(text);
                         }
                         if (div.firstChild)
                             div.firstChild.data = sDisplayString;
@@ -302,9 +306,9 @@ function loadLiveGridInfo()
                     sort : "created_by",
                     width: "20%",           
                     set: function  (div, text) {
-                        var nId = parseInt(text);                                           
+                        var nId = parseInt(text);
                         function cb_fetchUserFromCache(){
-                            return function (arg)                       
+                            return function (arg)
                             {
                                 if (div.firstChild)
                                     div.firstChild.data = arg[nId].display_name;
