@@ -207,6 +207,11 @@ function LiveGrid(columns, selection, module) {
 		from = Math.max(from, Self.from);
 		to = Math.min(to, Self.to);
 		for (var i = from; i < to; i++) Self.unfetched[i] = true;
+        if (Self.hoverIndex !== undefined &&
+            Self.hoverIndex >= from && Self.hoverIndex < to)
+        {
+            Self.hover.reset();
+        }
 		Self.doScroll();
 		Self.updateStyles();
 		Self.events.trigger("Changed", Self.storage);
@@ -432,12 +437,13 @@ LiveGrid.prototype = {
             return Hover.prototype.setSize.call(this, node);
         }
 		this.hover.onShow = function(node, manual) {
-			var i = node.oxRowIndex;
-			if (i !== undefined)
-				callback(Self.storage.ids[i], manual);
+			Self.hoverIndex = node.oxRowIndex;
+			if (Self.hoverIndex !== undefined)
+				callback(Self.storage.ids[Self.hoverIndex], manual);
 			else
 				return false;
-		}
+		};
+		this.hover.onHide = function() { Self.hoverIndex = undefined; };
 		return this.hover;
 	},
 	
@@ -1203,6 +1209,11 @@ function LiveGrid2(columns, selection, module) {
         from = Math.max(from, Self.from);
         to = Math.min(to, Self.to);
         for (var i = from; i < to; i++) Self.unfetched[i] = true;
+        if (Self.hoverIndex !== undefined &&
+            Self.hoverIndex >= from && Self.hoverIndex < to)
+        {
+            Self.hover.reset();
+        }
         Self.doScroll();
         Self.updateStyles();
     };
@@ -1438,12 +1449,13 @@ LiveGrid2.prototype = {
             return Hover.prototype.setSize.call(this, node);
         }
         this.hover.onShow = function(node, manual) {
-            var i = node.oxRowIndex;
-            if (i !== undefined)
-                callback(Self.collection.objects[i], manual);
+            Self.hoverIndex = node.oxRowIndex;
+            if (Self.hoverIndex !== undefined)
+                callback(Self.collection.objects[Self.hoverIndex], manual);
             else
                 return false;
-        }
+        };
+        this.hover.onHide = function() { Self.hoverIndex = undefined; };
         return this.hover;
     },
     
