@@ -817,6 +817,8 @@ com_openexchange_subscribe.generate_refresh_button("calendar");
  */
 com_openexchange_subscribe.buttons = {};
 com_openexchange_subscribe.func_button_refresh_subscription_folder = function(modulename) {
+    var subscribe = ox.desktop.getWidget(modulename + "-socialOX-subscribe");
+    
     // already initialized!?
     if (com_openexchange_subscribe.buttons[modulename] === undefined) {
         var refresh = ox.desktop.getWidget(modulename + "-socialOX-refresh");
@@ -866,7 +868,6 @@ com_openexchange_subscribe.func_button_refresh_subscription_folder = function(mo
             };
         };
         
-        var subscribe = ox.desktop.getWidget(modulename + "-socialOX-subscribe");
         // only set if button is available
         if (subscribe && subscribe.options) {
             // add available subscribe services to button
@@ -875,7 +876,8 @@ com_openexchange_subscribe.func_button_refresh_subscription_folder = function(mo
                 for (var i in availableTypes) (function(type) {
                     var def = availableTypes[type];
                     subscribe.add(new ox.gui.MenuItem({ 
-                            title: noI18n(def.displayName), 
+                            title: noI18n(def.displayName),
+                            id: modulename + "-socialOX-subscribe-" + type,
                             action: function() {
                                 // switch to properties and tab
                                 triggerEvent("Feature_Subscriptions");
@@ -897,6 +899,17 @@ com_openexchange_subscribe.func_button_refresh_subscription_folder = function(mo
         // intitialized
         com_openexchange_subscribe.buttons[modulename] = true;
     }
+    
+    // Update available subscriptions based on the current folder
+    if (subscribe && subscribe.options) {
+        var availableTypes = com_openexchange_subscribe.modules[modulename];
+        for (var type in availableTypes || {}) {
+            ox.desktop.getWidget(modulename + "-socialOX-subscribe-" + type)
+                .setVisible(!type.match(/.google.calendar$/) ||
+                    String(activefolder) !==
+                    String(ox.api.config.get('folder.calendar')));
+        }
+    }
 };
 
 function refreshFolder(options) {
